@@ -17,6 +17,7 @@ from .twitter_globals import POST_ACTIONS
 from .auth import NoAuth
 
 import re
+import sys
 import gzip
 
 try:
@@ -128,6 +129,13 @@ def wrap_response(response, headers):
         res = response
     return res
 
+def method_for_uri(uri):
+    method = "GET"
+    for action in POST_ACTIONS:
+        if re.search("%s(/\d+)?$" % action, uri):
+            method = "POST"
+            break
+    return method
 
 class TwitterCall(object):
 
@@ -168,13 +176,7 @@ class TwitterCall(object):
             uriparts.append(str(kwargs.pop(uripart, uripart)))
         uri = '/'.join(uriparts)
 
-        method = kwargs.pop('_method', None)
-        if not method:
-            method = "GET"
-            for action in POST_ACTIONS:
-                if re.search("%s(/\d+)?$" % action, uri):
-                    method = "POST"
-                    break
+        method = kwargs.pop('_method', None) or method_for_uri(uri)
 
         # If an id kwarg is present and there is no id to fill in in
         # the list of uriparts, assume the id goes at the end.
@@ -200,14 +202,32 @@ class TwitterCall(object):
         uriBase = "http%s://%s/%s%s%s" % (
             secure_str, self.domain, uri, dot, self.format)
 
+        # Check if argument tells whether img is already base64 encoded
+        b64_convert = True
+        if "_base64" in kwargs:
+            b64_convert = not kwargs.pop("_base64")
+        if b64_convert:
+            import base64
+
         # Catch media arguments to handle oauth query differently for multipart
         media = None
-        for arg in ['media[]', 'banner', 'image']:
+        for arg in ['media[]']:
             if arg in kwargs:
                 media = kwargs.pop(arg)
+                if b64_convert:
+                    media = base64.b64encode(media)
+                if sys.version_info >= (3, 0):
+                    media = str(media, 'utf8')
                 mediafield = arg
                 break
 
+        # Catch media arguments that are not accepted through multipart
+        # and are not yet base64 encoded
+        if b64_convert:
+            for arg in ['banner', 'image']:
+                if arg in kwargs:
+                    kwargs[arg] = base64.b64encode(kwargs[arg])
+
         headers = {'Accept-Encoding': 'gzip'} if self.gzip else dict()
         body = None
         arg_data = None
@@ -229,6 +249,7 @@ class TwitterCall(object):
             bod.append('--' + BOUNDARY)
             bod.append(
                 'Content-Disposition: form-data; name="%s"' % mediafield)
+            bod.append('Content-Transfer-Encoding: base64')
             bod.append('')
             bod.append(media)
             for k, v in kwargs.items():
@@ -237,7 +258,7 @@ class TwitterCall(object):
                 bod.append('')
                 bod.append(v)
             bod.append('--' + BOUNDARY + '--')
-            body = '\r\n'.join(bod)
+            body = '\r\n'.join(bod).encode('utf8')
             headers['Content-Type'] = \
                 'multipart/form-data; boundary=%s' % BOUNDARY
 
@@ -263,7 +284,9 @@ class TwitterCall(object):
                 buf = StringIO(data)
                 f = gzip.GzipFile(fileobj=buf)
                 data = f.read()
-            if "json" == self.format:
+            if len(data) == 0:
+                return wrap_response({}, handle.headers)
+            elif "json" == self.format:
                 res = json.loads(data.decode('utf8'))
                 return wrap_response(res, handle.headers)
             else:
@@ -290,14 +313,22 @@ class Twitter(TwitterCall):
 
     Examples::
 
+        from twitter import *
+
         t = Twitter(
             auth=OAuth(token, token_key, con_secret, con_secret_key)))
 
         # Get your "home" timeline
         t.statuses.home_timeline()
 
-        # Get a particular friend's tweets
-        t.statuses.user_timeline(user_id="billybob")
+        # Get a particular friend's timeline
+        t.statuses.user_timeline(screen_name="billybob")
+
+        # to pass in GET/POST parameters, such as `count`
+        t.statuses.home_timeline(count=5)
+
+        # to pass in the GET/POST parameter `id` you need to use `_id`
+        t.statuses.oembed(_id=1234567890)
 
         # Update your status
         t.statuses.update(
@@ -317,11 +348,26 @@ class Twitter(TwitterCall):
 
         # An *optional* `_timeout` parameter can also be used for API
         # calls which take much more time than normal or twitter stops
-        # responding for some reasone
+        # responding for some reason:
         t.users.lookup(
             screen_name=','.join(A_LIST_OF_100_SCREEN_NAMES), \
             _timeout=1)
 
+        # Overriding Method: GET/POST
+        # you should not need to use this method as this library properly
+        # detects whether GET or POST should be used, Nevertheless
+        # to force a particular method, use `_method`
+        t.statuses.oembed(_id=1234567890, _method='GET')
+
+        # Send a tweet with an image included (or set your banner or logo similarily)
+        # by just reading your image from the web or a file in a string:
+        with open("example.png", "rb") as imagefile:
+            params = {"media[]": imagefile.read(), "status": "PTT"}
+        t.statuses.update_with_media(**params)
+
+        # Or by sending a base64 encoded image:
+        params = {"media[]": base64_image, "status": "PTT", "_base64": True}
+        t.statuses.update_with_media(**params)
 
 
     Searching Twitter::
